#-----------------------------------------------------------------------------
#
# XDMFConfig.cmake - XDMF CMake configuration file for external projects.
#
# This file is configured by XDMF and used by the UseXDMF.cmake module
# to load XDMF's settings for an external project.

# Top level for development or install
SET(XDMF_INSTALL_DIR "/usr")

# The XDMF include file directories.
SET(XDMF_INCLUDE_DIRS "${XDMF_INSTALL_DIR}/include/;/usr/lib/openmpi/include;${XDMF_INSTALL_DIR}/include/utils")

# The XDMF library directories.
SET(XDMF_LIBRARY_DIRS "${XDMF_INSTALL_DIR}/lib")

# The location of the UseXDMF.cmake file.
SET(XDMF_USE_FILE "${XDMF_INSTALL_DIR}/lib/XdmfCMake/UseXDMF.cmake")

# The build settings file.
SET(XDMF_BUILD_SETTINGS_FILE "${XDMF_INSTALL_DIR}/lib/XdmfCMake/XDMFBuildSettings.cmake")

# The directory containing class list files for each kit.
SET(XDMF_KITS_DIR "${XDMF_INSTALL_DIR}/vtk")

# Utility libraries used by XDMF.
# To include a utility library in another project:
# LINK_DIRECTORIES(${XDMF_***_LIBRARY_PATH})
# TARGET_LINK_LIBRARIES(target ${XDMF_***_LIBRARIES})
SET(XDMF_HDF5_INCLUDE "/usr/lib/openmpi/include")
SET(XDMF_HDF5_LIBRARY_PATH "/usr/lib")
SET(XDMF_HDF5_LIBRARIES "/usr/lib/libhdf5.so")
SET(XDMF_SYSTEM_HDF5 "ON")

SET(XDMF_LIBXML2_INCLUDE "/usr/lib/vtk-5.6/vtklibxml2;/usr/include/vtk-5.6/vtklibxml2")
SET(XDMF_LIBXML2_LIBRARY_PATH "/usr/lib/vtk-5.6")
SET(XDMF_LIBXML2_LIBRARIES "/usr/lib/libxml2.so")
SET(XDMF_SYSTEM_LIBXML2 "ON")

SET(XDMF_ZLIB_INCLUDE "/usr/include/vtk-5.6;/usr/include/vtk-5.6/vtkzlib")
SET(XDMF_ZLIB_LIBRARY_PATH "/usr/lib/vtk-5.6")
SET(XDMF_ZLIB_LIBRARIES "/usr/lib/libz.so")
SET(XDMF_SYSTEM_ZLIB "ON")

# The XDMF library dependencies.
IF(NOT XDMF_NO_LIBRARY_DEPENDS)
  INCLUDE("${XDMF_INSTALL_DIR}/lib/XdmfCMake/XDMFLibraryDepends.cmake")
ENDIF(NOT XDMF_NO_LIBRARY_DEPENDS)

# Information about this particular XDMF Installation
SET(XDMF_BUILD_MPI "ON")
SET(XDMF_BUILD_UTILS "ON")
SET(XDMF_BUILD_VTK "ON")
SET(XDMF_WRAP_PYTHON "ON")

IF(XDMF_BUILD_MPI)
  SET(XDMF_MPI_LIBRARIES "/usr/lib/openmpi/lib/libmpi_cxx.so;/usr/lib/openmpi/lib/libmpi.so;/usr/lib/openmpi/lib/libopen-rte.so;/usr/lib/openmpi/lib/libopen-pal.so;/usr/lib/libdl.so;/usr/lib/libnsl.so;/usr/lib/libutil.so;/usr/lib/libm.so;/usr/lib/libdl.so")
  SET(XDMF_MPI_INCLUDE_PATH "/usr/lib/openmpi/include")
ENDIF(XDMF_BUILD_MPI)

IF(XDMF_BUILD_UTILS)
  SET(XDMF_EXODUSII_INCLUDE "/usr/include/vtkexodus2")
  SET(XDMF_EXODUSII_LIBRARY_PATH "/usr/lib")
  SET(XDMF_EXODUSII_LIBRARIES "vtkexoIIc")
  SET(XDMF_METIS_INCLUDE "/usr/lib/metis/include/metis")
  SET(XDMF_METIS_LIBRARY_PATH "/usr/lib/metis/lib")
  SET(XDMF_METIS_LIBRARIES "metis")
  SET(XDMF_NETCDF_INCLUDE "/usr/include/vtknetcdf")
  SET(XDMF_NETCDF_LIBRARY_PATH "/usr/lib")
  SET(XDMF_NETCDF_LIBRARIES "vtkNetCDF")
ENDIF(XDMF_BUILD_UTILS)

IF(XDMF_BUILD_VTK)
  SET(XDMF_VTK_DIR "/usr/lib/vtk")
ENDIF(XDMF_BUILD_VTK)
